powered by
Access model fit diagnostics from an xpdb object generated by xposeNlme.
get_overallNlme(xpdb, .problem = 1, .subprob = 0, .method = NULL)
A tibble for single problem/subproblem.
An xpose data base object from which the model output file data will be extracted. Only objects generated by xposeNlme are supported.
xpose
xposeNlme
The problem to be used.
The subproblem to be used.
The estimation method to be used.
# Store the parameter table prmOverall <- get_overallNlme(xpdb_ex_Nlme)
Run the code above in your browser using DataLab