# Store the parameter table
prm <- get_prmNlme(xpdb_ex_Nlme)
# Set the desired number of significant digits to display results
# Note: To have results displayed in the number of significant digits
# specified in the digits argument, one needs to make sure that
# the value of pillar.sigfig option (default value is 3) is greater
# than or equal to this specified value.
options(pillar.sigfig = 6)
get_prmNlme(xpdb_ex_Nlme, digits = 4)
Run the code above in your browser using DataLab