- xpdb
An xpose database object.
- covariate
Character; String of covariate name
- mapping
List of aesthetics mappings to be used for the xpose plot
(e.g. point_color).
- drop_fixed
Logical; logic specifying whether structural parameters having same value
for the given covariate value should be removed from plotting
- group
Grouping variable to be used for lines. ID by default
- type
Character; String setting the type of plot to be used.
Must be 'b' for categorical covariates,
one or a combination of 'p','l','s' for continuous covariates.
- title
Character; Plot title. Use NULL to remove.
- subtitle
Character; Plot subtitle. Use NULL to remove.
- caption
Character; Page caption. Use NULL to remove.
- tag
Character; Plot identification tag. Use NULL to remove.
- log
Character; String assigning logarithmic scale to axes, can be either '',
'x', y' or 'xy'.
- guide
Logical; Enable guide display (e.g. unity line).
- onlyfirst
Logical; Should the data be filtered to retain first value for each group/facet.
- facets
Either a character string to use facet_wrap_paginate
or a formula to use facet_grid_paginate.
- .problem
The $problem number to be used. By default returns
the last estimation problem.
- quiet
Logical, if FALSE messages are printed to the console.
- ...
Any additional aesthetics to be passed on xplot_scatter
or xplot_box.