Plot Residuals against a continuous or categorical covariate.
res_vs_cov(
xpdb,
mapping = NULL,
covariate,
res = "CWRES",
group = "ID",
type = "bpls",
title = "Residuals vs @x | @run",
subtitle = "Based on @nind individuals",
caption = "@dir",
tag = NULL,
log = NULL,
guide = TRUE,
facets,
.problem,
quiet,
...
)An object of class xpose_plot, ggplot, and gg. This object represents a customized plot created using ggplot2.
The xpose_plot class provides additional metadata and integration with xpose workflows, allowing for advanced
customization and compatibility with other xpose functions. Users can interact with the plot object as they
would with any ggplot2 object, including modifying aesthetics, adding layers, or saving the plot.
An xpose database object.
List of aesthetics mappings to be used for the xpose plot
(e.g. point_color).
Character; String of covariate name
Character; String of residual name; CWRES by default.
Grouping variable to be used for lines. ID by default
Character; String setting the type of plot to be used. Must be 'b' for categorical covariates, one or a combination of 'p','l','s' for continuous covariates.
Character; Plot title. Use NULL to remove.
Character; Plot subtitle. Use NULL to remove.
Character; Page caption. Use NULL to remove.
Character; Plot identification tag. Use NULL to remove.
Character; String assigning logarithmic scale to axes, can be either '', 'x', y' or 'xy'.
Logical; Should the guide (e.g. reference distribution) be displayed.
Either a character string to use facet_wrap_paginate
or a formula to use facet_grid_paginate.
The $problem number to be used. By default returns the last estimation problem.
Logical, if FALSE messages are printed to the console.
Any additional aesthetics to be passed on xplot_scatter
or xplot_box.
Plots can be customized by mapping arguments to specific layers. The naming convention is
layer_option where layer is one of the names defined in the list below and option is
any option supported by this layer e.g. boxplot_fill = 'blue', etc.
box plot: options to geom_boxplot
point plot: options to geom_point
line plot: options to geom_line
smooth plot: options to geom_smooth
xscale: options to scale_x_continuous or scale_x_log10
yscale: options to scale_y_continuous or scale_y_log10
xplot_scatter xplot_box
res_vs_cov(xpose::xpdb_ex_pk,
covariate = "SEX",
type = "b",
res = "WRES"
)
res_vs_cov(xpose::xpdb_ex_pk,
covariate = "AGE",
type = "ps",
res = c("CWRES", "WRES", "IRES", "IWRES")
)
Run the code above in your browser using DataLab